@@ -44,52 +44,6 @@
 
 #include "libblueman.h"
 
-char* get_net_address(char* iface, int _ioctl) {
-	int sock = socket(AF_INET, SOCK_STREAM, 0);
-	if (sock < 0) {
-		return NULL;
-	}
-		
-	struct ifreq ifr;
-	strncpy(ifr.ifr_name, iface, IFNAMSIZ);
-	
-	int err = ioctl(sock, _ioctl, &ifr);
-	if (err < 0) {
-		close(sock);
-		return NULL;
-	}
-	
-	return inet_ntoa(((struct sockaddr_in*) &ifr.ifr_addr)->sin_addr);
-}
-
-char** get_interface_list() {
-	int sock = socket(AF_INET, SOCK_STREAM, 0);
-	char** rets = NULL;
-	
-	struct ifconf ifc;
-	ifc.ifc_len = 128 * sizeof(struct ifreq);
-	ifc.ifc_req = malloc(ifc.ifc_len);
-	
-	int res = ioctl(sock, SIOCGIFCONF, &ifc);
-	if(res < 0) {
-
-	} else {
-		int size = ifc.ifc_len/sizeof(struct ifreq);
-	
-		rets = malloc((size+1)*sizeof(char*));
-		memset(rets, '\0', (size+1)*sizeof(char*));
-	
-		int i;
-		for(i = 0; i < size; i++) {
-			rets[i] = strdup(ifc.ifc_req[i].ifr_name);
-		}
-	}
-
-	close(sock);
-	free(ifc.ifc_req);
-	return rets;
-}
-
 static inline unsigned long __tv_to_jiffies(const struct timeval *tv)
 {
         unsigned long long jif;
@@ -319,7 +273,7 @@ get_rfcomm_channel(uint16_t service_class, char* btd_addr) {
     err = sdp_service_search_attr_req(session, search_list, SDP_ATTR_REQ_RANGE, attrid_list, &response_list);
 
     if (err) {
-        printf("Faild to search attributes\n");
+        printf("Failed to search attributes\n");
         sdp_list_free(response_list, 0);
         sdp_list_free(search_list, 0);
         sdp_list_free(attrid_list, 0);
