@@ -26,6 +26,7 @@ int connection_get_rssi(struct conn_info_handles *ci, int8_t *ret_rssi);
 int connection_get_lq(struct conn_info_handles *ci, uint8_t *ret_lq);
 int connection_get_tpl(struct conn_info_handles *ci, int8_t *ret_tpl, uint8_t type);
 int connection_close(struct conn_info_handles *ci);
+int get_rfcomm_channel(uint16_t uuid, char* btd_addr);
 int get_rfcomm_list(struct rfcomm_dev_list_req **result);
 int create_rfcomm_device(char *local_address, char *remote_address, int channel);
 int release_rfcomm_device(int id);
@@ -33,5 +34,3 @@ float get_page_timeout(int hdev);
 
 int _create_bridge(const char* name);
 int _destroy_bridge(const char* name);
-char* get_net_address(char* iface, int _ioctl);
-char** get_interface_list();
